@@ -32,7 +32,7 @@ use Math::Symbolic::ExportConstants qw/:all/;
 
 use base 'Math::Symbolic::Base';
 
-our $VERSION = '0.130';
+our $VERSION = '0.131';
 
 =head1 METHODS
 
@@ -159,8 +159,7 @@ sub value {
 
 =head2 Method signature
 
-signature() returns a tree's signature. (Which is the empty list in case
-of constants.)
+signature() returns a tree's signature.
 
 In the context of Math::Symbolic, signatures are the list of variables
 any given tree depends on. That means the tree "v*t+x" depends on the
@@ -179,12 +178,28 @@ in mechanics, the acceleration of a particle depends on its mass and
 the sum of all forces acting on it. So the variable 'acceleration' would
 have the signature ('acceleration', 'force1', 'force2',..., 'mass', 'time').
 
+If you're just looking for a list of the names of all variables in the tree,
+you should use the explicit_signature() method instead.
+
 =cut
 
 sub signature {
     return ();
 }
 
+=head2 Method explicit_signature
+
+explicit_signature() returns a lexicographically sorted list of
+variable names in the tree.
+
+See also: signature().
+
+=cut
+
+sub explicit_signature {
+    return ();
+}
+
 =head2 Method special
 
 Optional argument: sets the object's special attribute.
